// Craig S. Kaplan
// Draw a blizzard by creating a random composition of snowflake SVG
// illustrations.  Demonstrates loading a large number of SVGs into
// a single sketch.  Note that this is adapted from an assignment in
// CS 116X Winter 2015: 
// https://www.student.cs.uwaterloo.ca/~cs106/Winter2015/assignments/a05/a05.pdf

// ** This is a very slightly enhanced version of the Blizzard
// sketch that uses blur to create a lovely defocus effect.  You
// definitely don't need to understand how this works right now,
// but I thought it would be fun to share.

// We're going to hold on to a bunch of PShapes, so it makes
// sense to stick them into an array.
PShape[] shapes;

void setup()
{
  size( 500, 500 );

  shapes = new PShape[ 12 ];

  for ( int idx = 0; idx < 12; ++idx ) {
    // Now *this* is very interesting, take notice!
    // The information we pass as a parameter to 
    // loadShape() is just a String like any other.
    // So there's no reason it has to be a literal --
    // we can "generate" the file name using code
    // and then load that file into the right slot in
    // the array.  That way we save a lot of code
    // (though it took a while to write this comment...)
    shapes[idx] = loadShape( "snowflake" + (idx+1) + ".svg" );
  }
}

void draw()
{
  background( 180, 180, 255 );

  // Draw a bunch of snowflakes of progressively larger
  // sizes, 40 for each size.
  for ( int sz = 0; sz < 7; ++sz ) {
    float dim = 15 + sz*5;
    
    // Blur all the snowflakes you drew last time.  The
    // idea is that you draw smaller snowflakes and then
    // blur them, as if they're being photographed with
    // a lens that's in focus only for the close-up 
    // flakes.  The smallest snowflakes will undergo multiple
    // rounds of blurring, making them look even more 
    // out of focus.  See the reference for filter().
    filter( BLUR, 1 );
    
    for ( int idx = 0; idx < 40; ++idx ) {
      int which = int( random( shapes.length ) );
      float x = random( width );
      float y = random( height );

      shape( shapes[which], x, y, dim, dim );
    }
  }

  noLoop();
}

void keyPressed()
{
  save( "output.png" );
}