// Craig S. Kaplan
// A demonstration of capturing a complicated mathematical pattern
// as a PDF, which you might then incorporate into the rest of your
// workflow.  Move the mouse around to change the pattern, then
// press the 's' key to save it as a PDF.

import processing.pdf.*;

boolean recording = false;

void setup()
{
  size( 800, 400 );
}

void draw()
{
  // Follow the usual idiom of a global "recording" variable.
  if( recording ) {
    beginRecord( PDF, "output.pdf" );
  }
  
  noFill();
  stroke( 255 );
  background( 50 );
  
  // Draw some funky circles.  The explanation for why you
  // get the particular patterns you do is irrelevant for this
  // course and I won't explain it here.  But feel free to 
  // ask me about it, or to experiment with different patterns.
  for( int idx = 0; idx < width; idx += 10 ) {
    float factor = map( mouseX, 0, width, 1, 200 );
    float diam = map( sin( idx / factor ), -1, 1, 10, 300 );
    ellipse( idx, 200, diam, diam );
  }
  
  if( recording ) {
    endRecord();
    recording = false;
  }
}

void keyPressed()
{
  if( key == 's' ) {
    recording = true;
  }
}